==> ejc-dxcheck-impl-3.0.0-20240815.040059-123-sources.jar: com/ejianc/business/dxcheck/service/impl/UserServiceImpl.java <==
package com.ejianc.business.dxcheck.service.impl;/* author Wyx */

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dxcheck.entity.UserEntity;
import com.ejianc.business.dxcheck.mapper.UserMapper;
import com.ejianc.business.dxcheck.service.UserService;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

@Service("userService")
public class UserServiceImpl extends BaseServiceImpl<UserMapper, UserEntity> implements UserService {
    @Autowired
    private IOrgApi iOrgApi;
    // 租户ID
    private static final Long TENANT_ID = 999999L;
    // 总公司名称
    private static final String HEAD_COMPANY = "中国能源建设集团浙江火电建设有限公司本部";

    @Override
    public IPage<OrgVO> OrgTree(QueryParam param, int orgType) {
        String orgName;
        String orgName2 = null;
        switch (orgType) {
            case 1:
                orgName = HEAD_COMPANY;
                break;
            case 2:
                orgName = "浙江火电直管项目";
                break;
            case 3:
                orgName = "浙江火电分公司";
                orgName2 = "浙江火电子公司";
                break;
            default:
                orgName = "";
        }

        // 获取父类组织ID
        CommonResponse<OrgVO> OrgP = iOrgApi.findByNameAndTenantId(orgName, TENANT_ID);
        CommonResponse<OrgVO> OrgP2 = null;
        // 通过父类组织ID来查子类列表
        CommonResponse<List<OrgVO>> OrgCList = iOrgApi.getDirectChildrenByPid(OrgP.getData().getId(), "");
        List<OrgVO> data = OrgCList.getData();
        if (orgName2 != null) {
            OrgP2 = iOrgApi.findByNameAndTenantId(orgName2, TENANT_ID);
            if (OrgP2 != null) {
                if (OrgP2.getData() != null) {
                    CommonResponse<List<OrgVO>> OrgCList2 = iOrgApi.getDirectChildrenByPid(OrgP2.getData().getId(), "");
                    data.addAll(OrgCList2.getData());
                }
            }
        }
        String name = param.getSearchText().split(",")[1];
        if (StrUtil.isNotBlank(name) && !"null".equals(name)) {
            data = data.stream().filter(e -> e.getName().contains(name)).collect(Collectors.toList());
        }
        // 分子公司数据合并
        IPage<OrgVO> iPage = new Page<>(param.getPageIndex(), param.getPageSize());
        int total = data.size();
        iPage.setTotal(total);
        List<OrgVO> orgVOS = Collections.emptyList();
        try {
            orgVOS = OrgCList.getData().subList((param.getPageIndex() - 1) * param.getPageSize(),
                Math.min(param.getPageIndex() * param.getPageSize(), total));
        } catch (Exception e) {
            // 截取长度报错
            if (e instanceof IllegalArgumentException) {
                orgVOS = OrgCList.getData().subList(0, 10);
                iPage.setCurrent(1L);
            }
        }

        iPage.setRecords(orgVOS);

        return iPage;
    }

}

==> ejc-dxcheck-impl-3.0.0-20240823.064303-131-sources.jar: com/ejianc/business/dxcheck/service/impl/UserServiceImpl.java <==
package com.ejianc.business.dxcheck.service.impl;/* author Wyx */

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dxcheck.entity.UserEntity;
import com.ejianc.business.dxcheck.mapper.UserMapper;
import com.ejianc.business.dxcheck.service.UserService;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

@Service("userService")
public class UserServiceImpl extends BaseServiceImpl<UserMapper, UserEntity> implements UserService {
    @Autowired
    private IOrgApi iOrgApi;
    // 租户ID
    private static final Long TENANT_ID = 999999L;
    // 总公司名称
    private static final String HEAD_COMPANY = "中国能源建设集团浙江火电建设有限公司本部";

    @Override
    public IPage<OrgVO> OrgTree(QueryParam param, int orgType) {
        String orgName;
        String orgName2 = null;
        switch (orgType) {
            case 1:
                orgName = HEAD_COMPANY;
                break;
            case 2:
                orgName = "浙江火电直管项目";
                break;
            case 3:
                orgName = "浙江火电分公司";
                orgName2 = "浙江火电子公司";
                break;
            default:
                orgName = "";
        }

        // 获取父类组织ID
        CommonResponse<OrgVO> OrgP = iOrgApi.findByNameAndTenantId(orgName, TENANT_ID);
        CommonResponse<OrgVO> OrgP2 = null;
        // 通过父类组织ID来查子类列表
        CommonResponse<List<OrgVO>> OrgCList = iOrgApi.getDirectChildrenByPid(OrgP.getData().getId(), "");
        List<OrgVO> data = OrgCList.getData();
        if (orgName2 != null) {
            OrgP2 = iOrgApi.findByNameAndTenantId(orgName2, TENANT_ID);
            if (OrgP2 != null) {
                if (OrgP2.getData() != null) {
                    CommonResponse<List<OrgVO>> OrgCList2 = iOrgApi.getDirectChildrenByPid(OrgP2.getData().getId(), "");
                    data.addAll(OrgCList2.getData());
                }
            }
        }
        String name = param.getSearchText().split(",")[1];
        if (StrUtil.isNotBlank(name) && !"null".equals(name)) {
            data = data.stream().filter(e -> e.getName().contains(name)).collect(Collectors.toList());
        }
        // 分子公司数据合并
        IPage<OrgVO> iPage = new Page<>(param.getPageIndex(), param.getPageSize());
        int total = data.size();
        iPage.setTotal(total);
        List<OrgVO> orgVOS = Collections.emptyList();
        try {
            orgVOS = data.subList((param.getPageIndex() - 1) * param.getPageSize(),
                Math.min(param.getPageIndex() * param.getPageSize(), total));
        } catch (Exception e) {
            // 截取长度报错
            if (e instanceof IllegalArgumentException) {
                orgVOS = data.subList(0, 10);
                iPage.setCurrent(1L);
            }
        }

        iPage.setRecords(orgVOS);

        return iPage;
    }

}
